
#include "libprefs.h"
#include <stdio.h>


void
error(
	const char *		func,
	status_t			err)
{
	printf("error %08x: %s\n", err, func);
	exit(1);
}


void
main()
{
	uint32 version = 0, min_version = 0;
	status_t err = 0;
	PREFHandle handle = 0;
	PREFHandle other_app = 0;
	uint32 app_cookie = 0;
	uint32 list_cookie = 0;
	char app_name[256];
	char set_name[256];

	const char * verstr = PREFVersion(&version, &min_version);
	if (!verstr) error("PREFVersion", PREF_NOT_FOUND);
	puts(verstr);

	err = PREFInit("x-common", &handle);
	if (err) error("PREFInit", err);

	while (1) {
		err = PREFListApplications(handle, true, &app_cookie, app_name, 256);
		if (err == PREF_NOT_FOUND) break;
		if (err < B_OK) error("PREFListApplications", err);
		printf("user app: %s\n", app_name);

		err = PREFInit(app_name, &other_app);
		if (err < B_OK) error("PREFInit (other app)", err);
		list_cookie = 0;
		while (1) {
			PREFData set;
			err = PREFListSets(other_app, true, &list_cookie, set_name, 256);
			if (err == PREF_NOT_FOUND) break;
			if (err < B_OK) error("PREFListSets", err);
			printf("user set: %s - %s\n", app_name, set_name);
			if (!PREFLoadSet(other_app, set_name, true, &set)) {
				uint32 type = 0;
				uint32 cookie = 0;
				while (!PREFListData(set, &cookie, set_name, 256, &type))
				{
					printf("set data: %s - %.4s\n", set_name, &type);
				}
				PREFDisposeSet(&set);
			}
		}
		PREFDisposeSetCookie(other_app, list_cookie);
		PREFShutdown(other_app);
	}
	PREFDisposeApplicationCookie(handle, app_cookie);

	app_cookie = 0;
	while (1) {
		err = PREFListApplications(handle, false, &app_cookie, app_name, 256);
		if (err < B_OK) break;
		printf("common app: %s\n", app_name);

		err = PREFInit(app_name, &other_app);
		if (err < B_OK) error("PREFInit (other app)", err);
		list_cookie = 0;
		while (1) {
			err = PREFListSets(other_app, false, &list_cookie, set_name, 256);
			if (err == PREF_NOT_FOUND) break;
			if (err < B_OK) error("PREFListSets", err);
			printf("common set: %s - %s\n", app_name, set_name);
		}
		PREFDisposeSetCookie(other_app, list_cookie);
		PREFShutdown(other_app);
	}
	PREFDisposeApplicationCookie(handle, app_cookie);

	err = PREFShutdown(handle);
	if (err) error("PREFShutdown", err);
}

